==> nextcloud-16.0.5.tgz: nextcloud/apps/serverinfo/l10n/it.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informazioni CPU non disponibili",
    "Load average" : "Carico medio",
    "Last minute" : "Ultimo minuto",
    "Memory info not available" : "Informazioni memoria non disponibili",
    "Total" : "Totale",
    "Current usage" : "Utilizzo attuale",
    "Users" : "Utenti",
    "Groups" : "Gruppi",
    "Links" : "Collegamenti",
    "Mails" : "Messaggi di posta",
    "Federated sent" : "Federati inviati",
    "Federated received" : "Federati ricevuti",
    "Talk conversations" : "Conversazioni di Talk",
    "24 hours" : "24 ore",
    "1 hour" : "1 ora",
    "5 mins" : "5 minuti",
    "Copy" : "Copia",
    "Copied!" : "Copiati!",
    "Not supported!" : "Non supportato!",
    "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
    "System" : "Sistema",
    "Monitoring" : "Monitoraggio",
    "Monitoring app with useful server information" : "Applicazione di monitoraggio con informazioni utili sul server",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornisce informazioni utili sul server, come carico della CPU, utilizzo della memoria, utilizzo del disco, numero di utenti, ecc.",
    "Operating System" : "Sistema operativo",
    "CPU" : "CPU",
    "Memory" : "Memoria",
    "Server time" : "Ora del server",
    "Uptime" : "Uptime",
    "Time Servers" : "Server dell'ora",
    "Load" : "Carico",
    "Disk" : "Disco",
    "Mount" : "Mount",
    "Filesystem" : "Filesystem",
    "Size" : "Dimensione",
    "Available" : "Disponibile",
    "Used" : "Utilizzati",
    "You will get a notification once one of your disks is nearly full." : "Riceverai una notifica quando un dei dischi è prossimo alla capienza massima.",
    "Files:" : "File:",
    "Storages:" : "Archiviazioni:",
    "Free Space:" : "Spazio libero:",
    "Network" : "Rete",
    "Hostname" : "Nome host",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Stato",
    "Speed" : "Velocità",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Utenti attivi",
    "Total users:" : "Utenti totali:",
    "Shares" : "Condivisioni",
    "PHP" : "PHP",
    "Version:" : "Versione:",
    "Memory Limit:" : "Limite memoria:",
    "Max Execution Time:" : "Tempo massimo di esecuzione:",
    "Upload max size:" : "Dimensione massima caricamento:",
    "Database" : "Database",
    "Type:" : "Tipo:",
    "Size:" : "Dimensione:",
    "External monitoring tool" : "Strumento di controllo esterno",
    "You can connect an external monitoring tool by using this end point:" : "Puoi collegare uno strumento di controllo esterno utilizzando questo terminatore: ",
    "Did you know?" : "Sapevi che?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "L'aggiunta di \"?format=json\" alla fine dell'UR restituisce il risultato in formato JSON!",
    "Last 24 hours" : "Ultime 24 ore",
    "Last 1 hour" : "Ultima ora",
    "Last 5 mins" : "Ultimi 5 minuti",
    "CPU load" : "Carico CPU",
    "Memory usage" : "Utilizzo della memoria",
    "Storage" : "Archiviazione",
    "Users:" : "Utenti:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Applicazioni installate:",
    "Apps updates available:" : "Aggiornamenti applicazioni disponibili:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.8.tgz: nextcloud/apps/serverinfo/l10n/it.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informazioni CPU non disponibili",
    "Load average" : "Carico medio",
    "Last minute" : "Ultimo minuto",
    "Memory info not available" : "Informazioni memoria non disponibili",
    "Total" : "Totale",
    "Current usage" : "Utilizzo attuale",
    "Users" : "Utenti",
    "Groups" : "Gruppi",
    "Links" : "Collegamenti",
    "Mails" : "Messaggi di posta",
    "Federated sent" : "Federati inviati",
    "Federated received" : "Federati ricevuti",
    "Talk conversations" : "Conversazioni di Talk",
    "24 hours" : "24 ore",
    "1 hour" : "1 ora",
    "5 mins" : "5 minuti",
    "Copy" : "Copia",
    "Copied!" : "Copiati!",
    "Not supported!" : "Non supportato!",
    "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
    "System" : "Sistema",
    "Monitoring" : "Monitoraggio",
    "Monitoring app with useful server information" : "Applicazione di monitoraggio con informazioni utili sul server",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornisce informazioni utili sul server, come carico della CPU, utilizzo della memoria, utilizzo del disco, numero di utenti, ecc.",
    "Operating System" : "Sistema operativo",
    "CPU" : "CPU",
    "Memory" : "Memoria",
    "Server time" : "Ora del server",
    "Uptime" : "Uptime",
    "Time Servers" : "Server dell'ora",
    "Load" : "Carico",
    "Disk" : "Disco",
    "Mount" : "Mount",
    "Filesystem" : "Filesystem",
    "Size" : "Dimensione",
    "Available" : "Disponibile",
    "Used" : "Utilizzati",
    "You will get a notification once one of your disks is nearly full." : "Riceverai una notifica quando uno dei dischi è prossimo alla capienza massima.",
    "Files:" : "File:",
    "Storages:" : "Archiviazioni:",
    "Free Space:" : "Spazio libero:",
    "Network" : "Rete",
    "Hostname" : "Nome host",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Stato",
    "Speed" : "Velocità",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Utenti attivi",
    "Total users:" : "Utenti totali:",
    "Shares" : "Condivisioni",
    "PHP" : "PHP",
    "Version:" : "Versione:",
    "Memory Limit:" : "Limite memoria:",
    "Max Execution Time:" : "Tempo massimo di esecuzione:",
    "Upload max size:" : "Dimensione massima caricamento:",
    "Database" : "Database",
    "Type:" : "Tipo:",
    "Size:" : "Dimensione:",
    "External monitoring tool" : "Strumento di controllo esterno",
    "You can connect an external monitoring tool by using this end point:" : "Puoi collegare uno strumento di controllo esterno utilizzando questo terminatore: ",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "L'aggiunta di \"?format=json\" alla fine dell'URL ti fornirà il risultato in JSON.",
    "Did you know?" : "Sapevi che?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "L'aggiunta di \"?format=json\" alla fine dell'URL restituisce il risultato in formato JSON!"
},
"nplurals=2; plural=(n != 1);");
